##########
preprocess
##########

.. automodule:: mola.cfd.preprocess
    :members:

.. automodule:: mola.cfd.preprocess.boundary_conditions
    :members:

.. automodule:: mola.cfd.preprocess.cfd_parameters
    :members:

.. automodule:: mola.cfd.preprocess.check
    :members:

.. automodule:: mola.cfd.preprocess.extractions
    :members:

.. automodule:: mola.cfd.preprocess.finalization
    :members:

.. automodule:: mola.cfd.preprocess.flow_generators
    :members:

.. automodule:: mola.cfd.preprocess.initialization
    :members:

.. automodule:: mola.cfd.preprocess.mesh
    :members:

.. automodule:: mola.cfd.preprocess.motion
    :members:

.. automodule:: mola.cfd.preprocess.run_manager
    :members:

.. automodule:: mola.cfd.preprocess.solver_specific_tools
    :members:

.. automodule:: mola.cfd.preprocess.write_cfd_files
    :members:
